# Copyright 2021 Vincent Texier <vit@free.fr>
#
# This software is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This software is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
import abc
from typing import List, Optional

from tikka.domains.entities.currency import Currency


class CurrenciesRepositoryInterface(abc.ABC):
    """
    CurrenciesRepositoryInterface class
    """

    @abc.abstractmethod
    def get(self, code_name: str) -> Optional[Currency]:
        """
        Return currency codename list

        :return:
        """
        raise NotImplementedError

    @abc.abstractmethod
    def code_names(self) -> list:
        """
        Return currency codename list

        :return:
        """
        raise NotImplementedError

    @abc.abstractmethod
    def names(self) -> list:
        """
        Return currency name list

        :return:
        """
        raise NotImplementedError

    @abc.abstractmethod
    def get_entry_point_urls(self, code_name: str) -> List[str]:
        """
        Return currency entry point urls

        :param code_name: Currency code name
        :return:
        """
        raise NotImplementedError



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'tikka/slots/pyqt/resources/gui/widgets/licence.ui'
#
# Created by: PyQt5 UI code generator 5.15.6
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_LicenceWidget(object):
    def setupUi(self, LicenceWidget):
        LicenceWidget.setObjectName("LicenceWidget")
        LicenceWidget.resize(410, 303)
        self.verticalLayout = QtWidgets.QVBoxLayout(LicenceWidget)
        self.verticalLayout.setObjectName("verticalLayout")
        self.textBrowser = QtWidgets.QTextBrowser(LicenceWidget)
        self.textBrowser.setObjectName("textBrowser")
        self.verticalLayout.addWidget(self.textBrowser)

        self.retranslateUi(LicenceWidget)
        QtCore.QMetaObject.connectSlotsByName(LicenceWidget)

    def retranslateUi(self, LicenceWidget):
        #  _translate = QtCore.QCoreApplication.translate
        LicenceWidget.setWindowTitle(_("Ğ1 licence"))



# Copyright 2021 Vincent Texier <vit@free.fr>
#
# This software is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This software is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
import hashlib
import random
from typing import Optional

from Crypto.Cipher import ChaCha20_Poly1305
from substrateinterface import Keypair

from tikka.domains.currencies import Currencies
from tikka.domains.entities.constants import WALLETS_NONCE_SIZE
from tikka.domains.entities.wallet import Wallet
from tikka.interfaces.adapters.repository.wallets import WalletsRepositoryInterface


class Wallets:
    """
    Wallets domain class
    """

    def __init__(self, repository: WalletsRepositoryInterface, currencies: Currencies):
        """
        Init Wallets domain

        :param repository: Database adapter instance
        :param currencies: Currencies domain instance
        """
        self.repository = repository
        self.currencies = currencies

    @staticmethod
    def create(keypair: Keypair, password: str) -> Wallet:
        """
        Return an encrypted Wallet instance from keypair and password

        Encryption use ChaCha20_Poly1305 protocol

        :param keypair: Keypair instance
        :param password: Clear password
        :return:
        """
        password_hash = hashlib.sha256(password.encode("utf-8")).digest()
        nonce = random_bytes(WALLETS_NONCE_SIZE)
        cypher = ChaCha20_Poly1305.new(key=password_hash, nonce=nonce)
        encrypted_private_key, mac_tag = cypher.encrypt_and_digest(keypair.private_key)
        return Wallet(
            address=keypair.ss58_address,
            crypto_type=keypair.crypto_type,
            encrypted_private_key=encrypted_private_key.hex(),
            encryption_nonce=nonce.hex(),
            encryption_mac_tag=mac_tag.hex(),
        )

    def new(self, keypair: Keypair, password: str) -> Wallet:
        """
        Create Wallet from keypair and password and add it to repository
        if wallet already exists, update password

        :param keypair: Seed hexadecimal string
        :param password: Password string
        :return:
        """
        wallet = self.create(keypair, password)

        if self.exists(keypair.ss58_address):
            self.update(wallet)
        else:
            self.add(wallet)

        return wallet

    def add(self, wallet: Wallet):
        """
        Add wallet

        :param wallet: Wallet instance
        :return:
        """
        # add wallet
        self.repository.add(wallet)

    def get(self, address: str) -> Optional[Wallet]:
        """
        Return Wallet instance from address

        :param address:
        :return:
        """
        return self.repository.get(address)

    def get_keypair(self, address: str, password: str) -> Optional[Keypair]:
        """
        Get Keypair instance from Wallet address

        :param address: Wallet address
        :param password: Wallet password
        :return:
        """
        wallet = self.get(address)
        if wallet is None:
            return None
        password_hash = hashlib.sha256(password.encode("utf-8")).digest()
        cypher = ChaCha20_Poly1305.new(
            key=password_hash, nonce=bytes.fromhex(wallet.encryption_nonce)
        )
        private_key = cypher.decrypt_and_verify(
            bytes.fromhex(wallet.encrypted_private_key),
            bytes.fromhex(wallet.encryption_mac_tag),
        )
        return Keypair.create_from_private_key(
            private_key=private_key,
            ss58_address=address,
            crypto_type=wallet.crypto_type,
            ss58_format=self.currencies.get_current().ss58_format,
        )

    def update(self, wallet: Wallet):
        """
        Update wallet

        :param wallet: Wallet instance
        :return:
        """
        self.repository.update(wallet)

    def delete(self, address: str) -> None:
        """
        Delete wallet in repository

        :param address: Wallet address to delete
        :return:
        """
        self.repository.delete(address)

    def exists(self, address: str) -> bool:
        """
        Return True if wallet with address exists in repository

        :param address: Address to check
        :return:
        """
        return self.repository.exists(address)


def random_bytes(size: int) -> bytes:
    """
    Return random bytes of given length

    :param size: Size of nonce in bytes
    :return:
    """
    return bytearray(random.getrandbits(8) for _ in range(size))



# Copyright 2021 Vincent Texier <vit@free.fr>
#
# This software is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This software is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
import logging
from typing import Optional

from substrateinterface import ExtrinsicReceipt
from substrateinterface.exceptions import SubstrateRequestException

from tikka.domains.entities.account import Account
from tikka.interfaces.adapters.network.transfers import NetworkTransfersInterface


class NetworkTransfers(NetworkTransfersInterface):
    """
    NetworkTransfers class
    """

    def send(
        self, sender_account: Account, recipient_address: str, amount: int
    ) -> Optional[ExtrinsicReceipt]:
        __doc__ = (  # pylint: disable=redefined-builtin, unused-variable
            NetworkTransfersInterface.send.__doc__
        )
        if not self.connections.is_connected():
            return None
        if self.connections.rpc.client is None:
            return None
        if sender_account.keypair is None:
            logging.error("NetworkTransfers.send: sender_account.keypair is None!")
            return None

        params = {"dest": recipient_address, "value": amount}
        call = self.connections.rpc.client.compose_call(
            call_module="Balances",
            call_function="transfer",
            call_params=params,
        )

        # Get payment info
        payment_info = self.connections.rpc.client.get_payment_info(
            call=call, keypair=sender_account.keypair
        )

        print("Payment info: ", payment_info)

        extrinsic = self.connections.rpc.client.create_signed_extrinsic(
            call=call, keypair=sender_account.keypair
        )

        try:
            # fixme: code stuck infinitely if no blocks are created on blockchain
            #       should have a timeout option
            receipt = self.connections.rpc.client.submit_extrinsic(
                extrinsic, wait_for_inclusion=True
            )
            logging.debug(
                "Extrinsic '%s' sent and included in block '%s'",
                receipt.extrinsic_hash,
                receipt.block_hash,
            )
        except SubstrateRequestException as exception:
            logging.exception(exception)
            return None

        if receipt.is_success is False:
            logging.error(receipt.error_message)

        return receipt

    def fees(
        self, sender_account: Account, recipient_address: str, amount: int
    ) -> Optional[int]:
        __doc__ = (  # pylint: disable=redefined-builtin, unused-variable
            NetworkTransfersInterface.send.__doc__
        )
        if not self.connections.is_connected():
            return None
        if self.connections.rpc.client is None:
            return None
        if sender_account.keypair is None:
            logging.error("NetworkTransfers.fees: sender_account.keypair is None!")
            return None

        params = {"dest": recipient_address, "value": amount}
        call = self.connections.rpc.client.compose_call(
            call_module="Balances",
            call_function="transfer",
            call_params=params,
        )

        try:
            # Get payment info
            payment_info = self.connections.rpc.client.get_payment_info(
                call=call, keypair=sender_account.keypair
            )
        except SubstrateRequestException as exception:
            logging.exception(exception)
            return None

        if payment_info is None:
            return None

        print("Payment info: ", payment_info)
        return payment_info["partialFee"]



# Copyright 2021 Vincent Texier <vit@free.fr>
#
# This software is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This software is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
import sys
from typing import TYPE_CHECKING, Any, List, Optional

from PyQt5 import QtGui
from PyQt5.QtGui import QIcon
from PyQt5.QtWidgets import (
    QApplication,
    QComboBox,
    QMainWindow,
    QTableWidgetItem,
    QWidget,
)

from tikka import __version__
from tikka.domains.application import Application
from tikka.domains.entities.account import Account
from tikka.domains.entities.address import DisplayAddress
from tikka.domains.entities.constants import DATA_PATH
from tikka.domains.entities.events import AccountEvent, CurrencyEvent, UnitEvent
from tikka.domains.entities.tab import Tab
from tikka.interfaces.adapters.repository.preferences import (
    SELECTED_TAB_PAGE_KEY,
    SELECTED_UNIT,
)
from tikka.slots.pyqt.entities.constants import (
    ICON_ACCOUNT_LOCKED,
    ICON_ACCOUNT_UNLOCKED,
)
from tikka.slots.pyqt.resources.gui.windows.main_window_rc import Ui_MainWindow
from tikka.slots.pyqt.widgets.account import AccountWidget
from tikka.slots.pyqt.widgets.account_list import AccountListWidget
from tikka.slots.pyqt.widgets.currency import CurrencyWidget
from tikka.slots.pyqt.widgets.licence import LicenceWidget
from tikka.slots.pyqt.widgets.nodes import NodesWidget
from tikka.slots.pyqt.windows.about import AboutWindow
from tikka.slots.pyqt.windows.account_create import AccountCreateWindow
from tikka.slots.pyqt.windows.account_import import AccountImportWindow
from tikka.slots.pyqt.windows.address_add import AddressAddWindow
from tikka.slots.pyqt.windows.configuration import ConfigurationWindow
from tikka.slots.pyqt.windows.v1_account_import import V1AccountImportWindow
from tikka.slots.pyqt.windows.v1_wallet_import import V1WalletImportWindow

if TYPE_CHECKING:
    pass


class MainWindow(QMainWindow, Ui_MainWindow):
    """
    MainWindow class
    """

    def __init__(self, application: Application, parent: Optional[QWidget] = None):
        """
        Init main window

        :param application: Application instance
        :param parent: QWidget instance
        """
        super().__init__(parent=parent)
        self.setupUi(self)

        self.application = application
        self._ = self.application.translator.gettext

        self.update_title()

        # tab widgets
        self.account_list_widget: Optional[AccountListWidget] = None

        # signals
        self.tabWidget.tabCloseRequested.connect(self.close_tab)

        # connect functions to menu actions
        # accounts menu
        self.actionQuit.triggered.connect(self.close)
        self.actionAccount_list.triggered.connect(self.add_account_list_tab)
        self.actionAdd_an_address.triggered.connect(self.open_add_address_window)
        self.actionImport_account.triggered.connect(self.open_import_account_window)
        self.actionCreate_account.triggered.connect(self.open_create_account_window)

        # V1 accounts menu
        self.actionV1Import_account.triggered.connect(
            self.open_v1_import_account_window
        )
        self.actionV1Import_a_Wallet.triggered.connect(
            self.open_v1_import_wallet_window
        )

        # network menu
        self.actionNodes.triggered.connect(self.add_nodes_tab)

        # help menu
        self.actionCurrency.triggered.connect(self.add_currency_tab)
        self.actionG1_licence.triggered.connect(self.add_licence_tab)
        self.actionConfiguration.triggered.connect(self.open_configuration_window)
        self.actionAbout.triggered.connect(self.open_about_window)

        # status bar
        self.unit_combo_box = QComboBox()
        self.statusbar.addPermanentWidget(self.unit_combo_box)
        self.init_units()

        # events
        self.unit_combo_box.activated.connect(self._on_unit_changed)

        # application events
        self.application.event_dispatcher.add_event_listener(
            CurrencyEvent.EVENT_TYPE_PRE_CHANGE, self.on_currency_event
        )
        self.application.event_dispatcher.add_event_listener(
            CurrencyEvent.EVENT_TYPE_CHANGED, self.on_currency_event
        )
        self.application.event_dispatcher.add_event_listener(
            AccountEvent.EVENT_TYPE_ADD, self.on_add_account_event
        )
        self.application.event_dispatcher.add_event_listener(
            AccountEvent.EVENT_TYPE_DELETE, self.on_delete_account_event
        )
        self.application.event_dispatcher.add_event_listener(
            AccountEvent.EVENT_TYPE_UPDATE, self.on_update_account_event
        )

        # open saved tabs
        self.init_tabs()

    def closeEvent(
        self, event: QtGui.QCloseEvent  # pylint: disable=unused-argument
    ) -> None:
        """
        Override close event

        :param event:
        :return:
        """
        # save tabs in repository
        self.save_tabs()

        # save tab selection in preferences
        self.application.preferences_repository.set(
            SELECTED_TAB_PAGE_KEY, self.tabWidget.currentIndex()
        )

        self.application.close()

    def init_units(self) -> None:
        """
        Init units combobox in status bar

        :return:
        """
        self.unit_combo_box.clear()

        self.unit_combo_box.addItems(self.application.amounts.get_register_names())
        preferences_selected_unit = self.application.preferences_repository.get(
            SELECTED_UNIT
        )
        if preferences_selected_unit is None:
            # set first unit in preferences
            self.application.preferences_repository.set(
                SELECTED_UNIT, self.application.amounts.get_register_keys()[0]
            )
            preferences_selected_unit = self.application.preferences_repository.get(
                SELECTED_UNIT
            )

        self.unit_combo_box.setCurrentIndex(
            self.application.amounts.get_register_keys().index(
                preferences_selected_unit
            )
        )

    def init_tabs(self):
        """
        Init tabs from repository

        :return:
        """
        # close all tabs
        self.tabWidget.clear()

        # fetch tabs from repository
        for tab in self.application.tab_repository.list():
            # if account tab...
            if tab.panel_class == AccountWidget.__name__:
                # get account from list
                for account in self.application.accounts.list:
                    if account.address == tab.id:
                        self.add_account_tab(account)
            elif tab.panel_class == CurrencyWidget.__name__:
                self.add_currency_tab()
            elif tab.panel_class == LicenceWidget.__name__:
                self.add_licence_tab()
            elif tab.panel_class == AccountListWidget.__name__:
                self.add_account_list_tab()
            elif tab.panel_class == NodesWidget.__name__:
                self.add_nodes_tab()

        # get preferences
        preferences_selected_page = self.application.preferences_repository.get(
            SELECTED_TAB_PAGE_KEY
        )
        if preferences_selected_page is not None:
            self.tabWidget.setCurrentIndex(int(preferences_selected_page))

    def save_tabs(self):
        """
        Save tabs in tab repository

        :return:
        """
        # clear table
        self.application.tab_repository.delete_all()
        # save tabwidget tabs in repository
        for index in range(0, self.tabWidget.count()):
            widget = self.tabWidget.widget(index)
            if isinstance(widget, AccountWidget):
                # save account tab in repository
                tab = Tab(widget.account.address, str(widget.__class__.__name__))
            else:
                tab = Tab(
                    str(widget.__class__.__name__), str(widget.__class__.__name__)
                )

            self.application.tab_repository.add(tab)

    def close_tab(self, index: int):
        """
        Close tab on signal

        :param index: Index of tab requested to close
        :return:
        """
        self.tabWidget.removeTab(index)

    def add_account_list_tab(self) -> None:
        """
        Open account list tab

        :return:
        """
        if len(self.get_tab_widgets_by_class(AccountListWidget)) == 0:
            account_list_widget = AccountListWidget(self.application, self.tabWidget)
            self.tabWidget.addTab(account_list_widget, self._("Account list"))
            # catch account list double click signal
            account_list_widget.tableWidget.itemDoubleClicked.connect(
                self.on_account_list_double_click
            )
            self.tabWidget.setCurrentIndex(self.tabWidget.count() - 1)

    def add_account_tab(self, account: Account):
        """
        Open account list tab

        :return:
        """
        if (
            len(
                [
                    widget
                    for widget in self.get_tab_widgets_by_class(AccountWidget)
                    if isinstance(widget, AccountWidget)
                    and widget.account.address == account.address
                ]
            )
            == 0
        ):
            icon = QIcon()
            if self.application.wallets.exists(account.address):
                if account.keypair is not None:
                    icon = QIcon(ICON_ACCOUNT_UNLOCKED)
                else:
                    icon = QIcon(ICON_ACCOUNT_LOCKED)

            self.tabWidget.addTab(
                AccountWidget(self.application, account, self.tabWidget),
                icon,
                DisplayAddress(account.address).shorten,
            )
            self.tabWidget.setCurrentIndex(self.tabWidget.count() - 1)

    def add_currency_tab(self):
        """
        Open currency tab

        :return:
        """
        if len(self.get_tab_widgets_by_class(CurrencyWidget)) == 0:
            self.tabWidget.addTab(
                CurrencyWidget(self.application, self.tabWidget), self._("Currency")
            )
            self.tabWidget.setCurrentIndex(self.tabWidget.count() - 1)

    def add_licence_tab(self):
        """
        Open licence tab

        :return:
        """
        if len(self.get_tab_widgets_by_class(LicenceWidget)) == 0:
            self.tabWidget.addTab(
                LicenceWidget(self.application, self.tabWidget), self._("Ğ1 licence")
            )
            self.tabWidget.setCurrentIndex(self.tabWidget.count() - 1)

    def add_nodes_tab(self):
        """
        Open network nodes tab

        :return:
        """
        if len(self.get_tab_widgets_by_class(NodesWidget)) == 0:
            self.tabWidget.addTab(
                NodesWidget(self.application, self.tabWidget), self._("Network nodes")
            )
            self.tabWidget.setCurrentIndex(self.tabWidget.count() - 1)

    def update_title(self):
        """
        Update window title with version and currency

        :return:
        """
        self.setWindowTitle(
            "Tikka {version} - {currency}".format(  # pylint: disable=consider-using-f-string
                version=__version__,
                currency=self.application.currencies.get_current().name,
            )
        )

    def open_add_address_window(self) -> None:
        """
        Open add address window

        :return:
        """
        AddressAddWindow(self.application, self).exec_()

    def open_import_account_window(self) -> None:
        """
        Open import account window

        :return:
        """
        AccountImportWindow(self.application, self).exec_()

    def open_create_account_window(self) -> None:
        """
        Open create account window

        :return:
        """
        AccountCreateWindow(self.application, self).exec_()

    def open_v1_import_account_window(self) -> None:
        """
        Open V1 import account window

        :return:
        """
        V1AccountImportWindow(self.application, self).exec_()

    def open_v1_import_wallet_window(self) -> None:
        """
        Open V1 import wallet window

        :return:
        """
        V1WalletImportWindow(self.application, self).exec_()

    def open_configuration_window(self) -> None:
        """
        Open configuration window

        :return:
        """
        ConfigurationWindow(self.application, self).exec_()

    def open_about_window(self) -> None:
        """
        Open about window

        :return:
        """
        AboutWindow(self).exec_()

    def on_currency_event(self, event: CurrencyEvent):
        """
        When a currency event is triggered

        :return:
        """
        if event.type == CurrencyEvent.EVENT_TYPE_PRE_CHANGE:
            self.save_tabs()
        else:
            self.update_title()
            self.init_tabs()

    def on_account_list_double_click(self, item: QTableWidgetItem):
        """
        When an account is double clicked in account list

        :param item: QTableWidgetItem instance
        :return:
        """
        account = self.application.accounts.list[item.row()]
        self.add_account_tab(account)

    def on_add_account_event(self, event: AccountEvent) -> None:
        """
        Triggered when an account is created

        :param event: AccountEvent instance
        :return:
        """
        self.add_account_tab(event.account)

    def on_update_account_event(self, event: AccountEvent) -> None:
        """
        Triggered when an account is updated

        :param event: AccountEvent instance
        :return:
        """
        index = 0
        for index in range(0, self.tabWidget.count()):
            widget = self.tabWidget.widget(index)
            if (
                isinstance(widget, AccountWidget)
                and widget.account.address == event.account.address
            ):
                break
        icon = QIcon()
        if self.application.wallets.exists(event.account.address):
            if event.account.keypair is not None:
                icon = QIcon(ICON_ACCOUNT_UNLOCKED)
            else:
                icon = QIcon(ICON_ACCOUNT_LOCKED)

        self.tabWidget.setTabIcon(index, icon)

    def on_delete_account_event(self, event: AccountEvent) -> None:
        """
        Triggered when an account is deleted

        :param event: AccountEvent instance
        :return:
        """
        for widget in self.get_tab_widgets_by_class(AccountWidget):
            if (
                isinstance(widget, AccountWidget)
                and widget.account.address == event.account.address
            ):
                self.tabWidget.removeTab(self.tabWidget.indexOf(widget))

    def _on_unit_changed(self) -> None:
        """
        Triggered when unit_combo_box selection changed

        :return:
        """
        unit_key = list(self.application.amounts.register.keys())[
            self.unit_combo_box.currentIndex()
        ]
        self.application.preferences_repository.set(SELECTED_UNIT, unit_key)
        self.application.event_dispatcher.dispatch_event(
            UnitEvent(UnitEvent.EVENT_TYPE_CHANGED)
        )

    def get_tab_widgets_by_class(self, widget_class: Any) -> List[QWidget]:
        """
        Return a list of widget which are instance of widget_class

        :param widget_class: Widget class
        :return:
        """
        widgets = []
        for index in range(0, self.tabWidget.count()):
            widget = self.tabWidget.widget(index)
            if isinstance(widget, widget_class):
                widgets.append(widget)

        return widgets


if __name__ == "__main__":
    qapp = QApplication(sys.argv)
    application_ = Application(DATA_PATH)
    MainWindow(application_).show()
    sys.exit(qapp.exec_())



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'tikka/slots/pyqt/resources/gui/widgets/nodes.ui'
#
# Created by: PyQt5 UI code generator 5.15.6
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_NodesWidget(object):
    def setupUi(self, NodesWidget):
        NodesWidget.setObjectName("NodesWidget")
        NodesWidget.resize(724, 526)
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(NodesWidget)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.gridLayout = QtWidgets.QGridLayout()
        self.gridLayout.setObjectName("gridLayout")
        self.label = QtWidgets.QLabel(NodesWidget)
        self.label.setObjectName("label")
        self.gridLayout.addWidget(self.label, 0, 0, 1, 1)
        self.entryPointComboBox = QtWidgets.QComboBox(NodesWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.entryPointComboBox.sizePolicy().hasHeightForWidth())
        self.entryPointComboBox.setSizePolicy(sizePolicy)
        self.entryPointComboBox.setToolTip("")
        self.entryPointComboBox.setEditable(True)
        self.entryPointComboBox.setMinimumContentsLength(0)
        self.entryPointComboBox.setObjectName("entryPointComboBox")
        self.gridLayout.addWidget(self.entryPointComboBox, 0, 1, 1, 1)
        self.connectButton = QtWidgets.QPushButton(NodesWidget)
        self.connectButton.setObjectName("connectButton")
        self.gridLayout.addWidget(self.connectButton, 0, 2, 1, 1)
        self.connectionStatusLabel = QtWidgets.QLabel(NodesWidget)
        self.connectionStatusLabel.setMaximumSize(QtCore.QSize(16, 16))
        self.connectionStatusLabel.setText("")
        self.connectionStatusLabel.setPixmap(QtGui.QPixmap(":/icons/disconnected"))
        self.connectionStatusLabel.setScaledContents(True)
        self.connectionStatusLabel.setObjectName("connectionStatusLabel")
        self.gridLayout.addWidget(self.connectionStatusLabel, 0, 3, 1, 1)
        self.refreshNodesButton = QtWidgets.QPushButton(NodesWidget)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/icons/refresh_icon"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.refreshNodesButton.setIcon(icon)
        self.refreshNodesButton.setObjectName("refreshNodesButton")
        self.gridLayout.addWidget(self.refreshNodesButton, 0, 4, 1, 1)
        self.verticalLayout_2.addLayout(self.gridLayout)
        self.nodesTableView = QtWidgets.QTableView(NodesWidget)
        self.nodesTableView.setContextMenuPolicy(QtCore.Qt.CustomContextMenu)
        self.nodesTableView.setEditTriggers(QtWidgets.QAbstractItemView.NoEditTriggers)
        self.nodesTableView.setSortingEnabled(True)
        self.nodesTableView.setObjectName("nodesTableView")
        self.nodesTableView.horizontalHeader().setStretchLastSection(True)
        self.nodesTableView.verticalHeader().setVisible(False)
        self.verticalLayout_2.addWidget(self.nodesTableView)

        self.retranslateUi(NodesWidget)
        QtCore.QMetaObject.connectSlotsByName(NodesWidget)

    def retranslateUi(self, NodesWidget):
        #  _translate = QtCore.QCoreApplication.translate
        NodesWidget.setWindowTitle(_("Network nodes"))
        self.label.setText(_("Entry point"))
        self.connectButton.setToolTip(_("Connection to entry point"))
        self.connectButton.setText(_("Connect"))
        self.refreshNodesButton.setToolTip(_("Refresh nodes from network"))
        self.refreshNodesButton.setText(_("Refresh"))
import tikka.slots.pyqt.resources.icons.index_rc
